.. meta::
  :copyright: SPDX-FileCopyrightText: Christian Amsüss and the aiocoap contributors
  :copyright: SPDX-License-Identifier: MIT

.. include_preprocessed:: ../README.rst

.. toctree::
   :maxdepth: 1

   installation
   guidedtour
   stateofoscore
   stateofedhoc

   api
   design

   examples
   tools
   pyodide
   faq
   news
   LICENSE
